# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/contrib/lgsvl_msgs/proto/detection2d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/contrib/lgsvl_msgs/proto/detection2d.proto',
  package='apollo.contrib.lgsvl_msgs',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/contrib/lgsvl_msgs/proto/detection2d.proto\x12\x19\x61pollo.contrib.lgsvl_msgs\x1a!modules/common/proto/header.proto\"D\n\rBoundingBox2D\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"p\n\x05Twist\x12\x32\n\x06linear\x18\x01 \x01(\x0b\x32\".apollo.contrib.lgsvl_msgs.Vector3\x12\x33\n\x07\x61ngular\x18\x02 \x01(\x0b\x32\".apollo.contrib.lgsvl_msgs.Vector3\"\xca\x01\n\x0b\x44\x65tection2D\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x01\x12\x36\n\x04\x62\x62ox\x18\x05 \x01(\x0b\x32(.apollo.contrib.lgsvl_msgs.BoundingBox2D\x12\x32\n\x08velocity\x18\x06 \x01(\x0b\x32 .apollo.contrib.lgsvl_msgs.Twistb\x06proto3'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_BOUNDINGBOX2D = _descriptor.Descriptor(
  name='BoundingBox2D',
  full_name='apollo.contrib.lgsvl_msgs.BoundingBox2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.contrib.lgsvl_msgs.BoundingBox2D.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.contrib.lgsvl_msgs.BoundingBox2D.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.contrib.lgsvl_msgs.BoundingBox2D.width', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.contrib.lgsvl_msgs.BoundingBox2D.height', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=184,
)


_VECTOR3 = _descriptor.Descriptor(
  name='Vector3',
  full_name='apollo.contrib.lgsvl_msgs.Vector3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.contrib.lgsvl_msgs.Vector3.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.contrib.lgsvl_msgs.Vector3.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.contrib.lgsvl_msgs.Vector3.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=228,
)


_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='apollo.contrib.lgsvl_msgs.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='apollo.contrib.lgsvl_msgs.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular', full_name='apollo.contrib.lgsvl_msgs.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=342,
)


_DETECTION2D = _descriptor.Descriptor(
  name='Detection2D',
  full_name='apollo.contrib.lgsvl_msgs.Detection2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.contrib.lgsvl_msgs.Detection2D.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.contrib.lgsvl_msgs.Detection2D.id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.contrib.lgsvl_msgs.Detection2D.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='apollo.contrib.lgsvl_msgs.Detection2D.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='apollo.contrib.lgsvl_msgs.Detection2D.bbox', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.contrib.lgsvl_msgs.Detection2D.velocity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=547,
)

_TWIST.fields_by_name['linear'].message_type = _VECTOR3
_TWIST.fields_by_name['angular'].message_type = _VECTOR3
_DETECTION2D.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_DETECTION2D.fields_by_name['bbox'].message_type = _BOUNDINGBOX2D
_DETECTION2D.fields_by_name['velocity'].message_type = _TWIST
DESCRIPTOR.message_types_by_name['BoundingBox2D'] = _BOUNDINGBOX2D
DESCRIPTOR.message_types_by_name['Vector3'] = _VECTOR3
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
DESCRIPTOR.message_types_by_name['Detection2D'] = _DETECTION2D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBox2D = _reflection.GeneratedProtocolMessageType('BoundingBox2D', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDINGBOX2D,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection2d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.BoundingBox2D)
  })
_sym_db.RegisterMessage(BoundingBox2D)

Vector3 = _reflection.GeneratedProtocolMessageType('Vector3', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR3,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection2d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Vector3)
  })
_sym_db.RegisterMessage(Vector3)

Twist = _reflection.GeneratedProtocolMessageType('Twist', (_message.Message,), {
  'DESCRIPTOR' : _TWIST,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection2d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Twist)
  })
_sym_db.RegisterMessage(Twist)

Detection2D = _reflection.GeneratedProtocolMessageType('Detection2D', (_message.Message,), {
  'DESCRIPTOR' : _DETECTION2D,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection2d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Detection2D)
  })
_sym_db.RegisterMessage(Detection2D)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planner_open_space_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.planning.proto.math import fem_pos_deviation_smoother_config_pb2 as modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2
from modules.planning.proto import task_config_pb2 as modules_dot_planning_dot_proto_dot_task__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planner_open_space_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6modules/planning/proto/planner_open_space_config.proto\x12\x0f\x61pollo.planning\x1a\x43modules/planning/proto/math/fem_pos_deviation_smoother_config.proto\x1a(modules/planning/proto/task_config.proto\"\xa2\x05\n\x16PlannerOpenSpaceConfig\x12.\n\nroi_config\x18\x01 \x01(\x0b\x32\x1a.apollo.planning.ROIConfig\x12;\n\x11warm_start_config\x18\x02 \x01(\x0b\x32 .apollo.planning.WarmStartConfig\x12U\n\x1f\x64ual_variable_warm_start_config\x18\x03 \x01(\x0b\x32,.apollo.planning.DualVariableWarmStartConfig\x12I\n\x18\x64istance_approach_config\x18\x04 \x01(\x0b\x32\'.apollo.planning.DistanceApproachConfig\x12V\n#iterative_anchoring_smoother_config\x18\x05 \x01(\x0b\x32).apollo.planning.IterativeAnchoringConfig\x12O\n\x1btrajectory_partition_config\x18\x06 \x01(\x0b\x32*.apollo.planning.TrajectoryPartitionConfig\x12\x12\n\x07\x64\x65lta_t\x18\x07 \x01(\x02:\x01\x31\x12,\n\x1dis_near_destination_threshold\x18\x08 \x01(\x01:\x05\x30.001\x12/\n enable_check_parallel_trajectory\x18\t \x01(\x08:\x05\x66\x61lse\x12*\n\x1b\x65nable_linear_interpolation\x18\n \x01(\x08:\x05\x66\x61lse\x12\x31\n#is_near_destination_theta_threshold\x18\x0b \x01(\x01:\x04\x30.05\"\x9d\x01\n\tROIConfig\x12(\n\x1croi_longitudinal_range_start\x18\x01 \x01(\x01:\x02\x31\x30\x12&\n\x1aroi_longitudinal_range_end\x18\x02 \x01(\x01:\x02\x31\x30\x12\x1e\n\x13parking_start_range\x18\x03 \x01(\x01:\x01\x37\x12\x1e\n\x0fparking_inwards\x18\x04 \x01(\x08:\x05\x66\x61lse\"\xc3\x03\n\x0fWarmStartConfig\x12\x1f\n\x12xy_grid_resolution\x18\x01 \x01(\x01:\x03\x30.2\x12!\n\x13phi_grid_resolution\x18\x02 \x01(\x01:\x04\x30.05\x12\x19\n\rnext_node_num\x18\x03 \x01(\x04:\x02\x31\x30\x12\x16\n\tstep_size\x18\x04 \x01(\x01:\x03\x30.5\x12\x1f\n\x14traj_forward_penalty\x18\x05 \x01(\x01:\x01\x30\x12\x1c\n\x11traj_back_penalty\x18\x06 \x01(\x01:\x01\x30\x12$\n\x18traj_gear_switch_penalty\x18\x07 \x01(\x01:\x02\x31\x30\x12\x1f\n\x12traj_steer_penalty\x18\x08 \x01(\x01:\x03\x31\x30\x30\x12%\n\x19traj_steer_change_penalty\x18\t \x01(\x01:\x02\x31\x30\x12&\n\x19grid_a_star_xy_resolution\x18\x0f \x01(\x01:\x03\x30.1\x12\x18\n\x0bnode_radius\x18\x10 \x01(\x01:\x03\x30.5\x12J\n\x0es_curve_config\x18\x11 \x01(\x0b\x32\x32.apollo.planning.PiecewiseJerkSpeedOptimizerConfig\"\x98\x02\n\x1b\x44ualVariableWarmStartConfig\x12\x13\n\x08weight_d\x18\x01 \x01(\x01:\x01\x31\x12\x32\n\x0cipopt_config\x18\x02 \x01(\x0b\x32\x1c.apollo.planning.IpoptConfig\x12\x32\n\tqp_format\x18\x03 \x01(\x0e\x32\x1f.apollo.planning.DualWarmUpMode\x12\x1e\n\x13min_safety_distance\x18\x04 \x01(\x01:\x01\x30\x12\x19\n\ndebug_osqp\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x04\x62\x65ta\x18\x06 \x01(\x01:\x01\x31\x12\x30\n\x0bosqp_config\x18\x07 \x01(\x0b\x32\x1b.apollo.planning.OSQPConfig\"\xd5\x07\n\x16\x44istanceApproachConfig\x12\x14\n\x0cweight_steer\x18\x01 \x01(\x01\x12\x10\n\x08weight_a\x18\x02 \x01(\x01\x12\x19\n\x11weight_steer_rate\x18\x03 \x01(\x01\x12\x15\n\rweight_a_rate\x18\x04 \x01(\x01\x12\x10\n\x08weight_x\x18\x05 \x01(\x01\x12\x10\n\x08weight_y\x18\x06 \x01(\x01\x12\x12\n\nweight_phi\x18\x07 \x01(\x01\x12\x10\n\x08weight_v\x18\x08 \x01(\x01\x12\x1e\n\x16weight_steer_stitching\x18\t \x01(\x01\x12\x1a\n\x12weight_a_stitching\x18\n \x01(\x01\x12\x1f\n\x17weight_first_order_time\x18\x0b \x01(\x01\x12 \n\x18weight_second_order_time\x18\x0c \x01(\x01\x12\x1e\n\x13min_safety_distance\x18\r \x01(\x01:\x01\x30\x12\x1c\n\x11max_speed_forward\x18\x0e \x01(\x01:\x01\x33\x12\x1c\n\x11max_speed_reverse\x18\x0f \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_forward\x18\x10 \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_reverse\x18\x11 \x01(\x01:\x01\x32\x12$\n\x17min_time_sample_scaling\x18\x12 \x01(\x01:\x03\x30.1\x12#\n\x17max_time_sample_scaling\x18\x13 \x01(\x01:\x02\x31\x30\x12\x1b\n\x0cuse_fix_time\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x32\n\x0cipopt_config\x18\x15 \x01(\x0b\x32\x1c.apollo.planning.IpoptConfig\x12\x1f\n\x17\x65nable_constraint_check\x18\x16 \x01(\x08\x12\x1e\n\x16\x65nable_hand_derivative\x18\x17 \x01(\x08\x12\x1f\n\x17\x65nable_derivative_check\x18\x18 \x01(\x08\x12)\n\x1a\x65nable_initial_final_check\x18\x19 \x01(\x08:\x05\x66\x61lse\x12\x45\n\x16\x64istance_approach_mode\x18\x1a \x01(\x0e\x32%.apollo.planning.DistanceApproachMode\x12!\n\x12\x65nable_jacobian_ad\x18\x1b \x01(\x08:\x05\x66\x61lse\x12)\n\x1a\x65nable_check_initial_state\x18\x1c \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x10weight_end_state\x18\x1d \x01(\x01:\x01\x30\x12\x17\n\x0cweight_slack\x18\x1e \x01(\x01:\x01\x30\"\xf9\x02\n\x0bIpoptConfig\x12\x19\n\x11ipopt_print_level\x18\x01 \x01(\x05\x12\x19\n\x11mumps_mem_percent\x18\x02 \x01(\x05\x12\x14\n\x0cmumps_pivtol\x18\x03 \x01(\x01\x12\x16\n\x0eipopt_max_iter\x18\x04 \x01(\x05\x12\x11\n\tipopt_tol\x18\x05 \x01(\x01\x12(\n ipopt_acceptable_constr_viol_tol\x18\x06 \x01(\x01\x12&\n\x1eipopt_min_hessian_perturbation\x18\x07 \x01(\x01\x12+\n#ipopt_jacobian_regularization_value\x18\x08 \x01(\x01\x12%\n\x1dipopt_print_timing_statistics\x18\t \x01(\t\x12\x19\n\x11ipopt_alpha_for_y\x18\n \x01(\t\x12\x16\n\x0eipopt_recalc_y\x18\x0b \x01(\t\x12\x1a\n\ripopt_mu_init\x18\x0c \x01(\x01:\x03\x30.1\"\x9c\x01\n\nOSQPConfig\x12\x10\n\x05\x61lpha\x18\x01 \x01(\x01:\x01\x31\x12\x16\n\x07\x65ps_abs\x18\x02 \x01(\x01:\x05\x30.001\x12\x16\n\x07\x65ps_rel\x18\x03 \x01(\x01:\x05\x30.001\x12\x17\n\x08max_iter\x18\x04 \x01(\x05:\x05\x31\x30\x30\x30\x30\x12\x14\n\x06polish\x18\x05 \x01(\x08:\x04true\x12\x1d\n\x0eosqp_debug_log\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xf9\x04\n\x18IterativeAnchoringConfig\x12!\n\x14interpolated_delta_s\x18\x01 \x01(\x01:\x03\x30.1\x12\"\n\x16reanchoring_trails_num\x18\x02 \x01(\x05:\x02\x35\x30\x12$\n\x16reanchoring_pos_stddev\x18\x03 \x01(\x01:\x04\x30.25\x12$\n\x19reanchoring_length_stddev\x18\x04 \x01(\x01:\x01\x31\x12\x1d\n\x0e\x65stimate_bound\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x18\n\rdefault_bound\x18\x06 \x01(\x01:\x01\x32\x12(\n\x1avehicle_shortest_dimension\x18\x07 \x01(\x01:\x04\x31.04\x12Y\n!fem_pos_deviation_smoother_config\x18\x08 \x01(\x0b\x32..apollo.planning.FemPosDeviationSmootherConfig\x12%\n\x18\x63ollision_decrease_ratio\x18\t \x01(\x01:\x03\x30.9\x12\x18\n\rmax_forward_v\x18\n \x01(\x01:\x01\x32\x12\x18\n\rmax_reverse_v\x18\x0b \x01(\x01:\x01\x32\x12\x1a\n\x0fmax_forward_acc\x18\x0c \x01(\x01:\x01\x33\x12\x1a\n\x0fmax_reverse_acc\x18\r \x01(\x01:\x01\x32\x12\x17\n\x0cmax_acc_jerk\x18\x0e \x01(\x01:\x01\x34\x12\x14\n\x07\x64\x65lta_t\x18\x0f \x01(\x01:\x03\x30.2\x12J\n\x0es_curve_config\x18\x10 \x01(\x0b\x32\x32.apollo.planning.PiecewiseJerkSpeedOptimizerConfig\"\xf2\x01\n\x19TrajectoryPartitionConfig\x12#\n\x17interpolated_pieces_num\x18\x01 \x01(\x04:\x02\x35\x30\x12%\n\x1ainitial_gear_check_horizon\x18\x02 \x01(\x04:\x01\x33\x12$\n\x17heading_searching_range\x18\x03 \x01(\x01:\x03\x30.3\x12%\n\x1agear_shift_period_duration\x18\x04 \x01(\x01:\x01\x32\x12\x1b\n\x10gear_shift_max_t\x18\x05 \x01(\x01:\x01\x33\x12\x1f\n\x11gear_shift_unit_t\x18\x06 \x01(\x01:\x04\x30.02*J\n\x0e\x44ualWarmUpMode\x12\t\n\x05IPOPT\x10\x00\x12\x0b\n\x07IPOPTQP\x10\x01\x12\x08\n\x04OSQP\x10\x02\x12\t\n\x05\x44\x45\x42UG\x10\x03\x12\x0b\n\x07SLACKQP\x10\x04*\xf7\x01\n\x14\x44istanceApproachMode\x12\x1b\n\x17\x44ISTANCE_APPROACH_IPOPT\x10\x00\x12 \n\x1c\x44ISTANCE_APPROACH_IPOPT_CUDA\x10\x01\x12$\n DISTANCE_APPROACH_IPOPT_FIXED_TS\x10\x02\x12&\n\"DISTANCE_APPROACH_IPOPT_FIXED_DUAL\x10\x03\x12%\n!DISTANCE_APPROACH_IPOPT_RELAX_END\x10\x04\x12+\n\'DISTANCE_APPROACH_IPOPT_RELAX_END_SLACK\x10\x05'
  ,
  dependencies=[modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_task__config__pb2.DESCRIPTOR,])

_DUALWARMUPMODE = _descriptor.EnumDescriptor(
  name='DualWarmUpMode',
  full_name='apollo.planning.DualWarmUpMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IPOPT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPOPTQP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OSQP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLACKQP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4164,
  serialized_end=4238,
)
_sym_db.RegisterEnumDescriptor(_DUALWARMUPMODE)

DualWarmUpMode = enum_type_wrapper.EnumTypeWrapper(_DUALWARMUPMODE)
_DISTANCEAPPROACHMODE = _descriptor.EnumDescriptor(
  name='DistanceApproachMode',
  full_name='apollo.planning.DistanceApproachMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT_CUDA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT_FIXED_TS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT_FIXED_DUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT_RELAX_END', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE_APPROACH_IPOPT_RELAX_END_SLACK', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4241,
  serialized_end=4488,
)
_sym_db.RegisterEnumDescriptor(_DISTANCEAPPROACHMODE)

DistanceApproachMode = enum_type_wrapper.EnumTypeWrapper(_DISTANCEAPPROACHMODE)
IPOPT = 0
IPOPTQP = 1
OSQP = 2
DEBUG = 3
SLACKQP = 4
DISTANCE_APPROACH_IPOPT = 0
DISTANCE_APPROACH_IPOPT_CUDA = 1
DISTANCE_APPROACH_IPOPT_FIXED_TS = 2
DISTANCE_APPROACH_IPOPT_FIXED_DUAL = 3
DISTANCE_APPROACH_IPOPT_RELAX_END = 4
DISTANCE_APPROACH_IPOPT_RELAX_END_SLACK = 5



_PLANNEROPENSPACECONFIG = _descriptor.Descriptor(
  name='PlannerOpenSpaceConfig',
  full_name='apollo.planning.PlannerOpenSpaceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roi_config', full_name='apollo.planning.PlannerOpenSpaceConfig.roi_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warm_start_config', full_name='apollo.planning.PlannerOpenSpaceConfig.warm_start_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dual_variable_warm_start_config', full_name='apollo.planning.PlannerOpenSpaceConfig.dual_variable_warm_start_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_approach_config', full_name='apollo.planning.PlannerOpenSpaceConfig.distance_approach_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iterative_anchoring_smoother_config', full_name='apollo.planning.PlannerOpenSpaceConfig.iterative_anchoring_smoother_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_partition_config', full_name='apollo.planning.PlannerOpenSpaceConfig.trajectory_partition_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_t', full_name='apollo.planning.PlannerOpenSpaceConfig.delta_t', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_destination_threshold', full_name='apollo.planning.PlannerOpenSpaceConfig.is_near_destination_threshold', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_check_parallel_trajectory', full_name='apollo.planning.PlannerOpenSpaceConfig.enable_check_parallel_trajectory', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_linear_interpolation', full_name='apollo.planning.PlannerOpenSpaceConfig.enable_linear_interpolation', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_destination_theta_threshold', full_name='apollo.planning.PlannerOpenSpaceConfig.is_near_destination_theta_threshold', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=861,
)


_ROICONFIG = _descriptor.Descriptor(
  name='ROIConfig',
  full_name='apollo.planning.ROIConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_start', full_name='apollo.planning.ROIConfig.roi_longitudinal_range_start', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_end', full_name='apollo.planning.ROIConfig.roi_longitudinal_range_end', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_start_range', full_name='apollo.planning.ROIConfig.parking_start_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_inwards', full_name='apollo.planning.ROIConfig.parking_inwards', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=1021,
)


_WARMSTARTCONFIG = _descriptor.Descriptor(
  name='WarmStartConfig',
  full_name='apollo.planning.WarmStartConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xy_grid_resolution', full_name='apollo.planning.WarmStartConfig.xy_grid_resolution', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phi_grid_resolution', full_name='apollo.planning.WarmStartConfig.phi_grid_resolution', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_node_num', full_name='apollo.planning.WarmStartConfig.next_node_num', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step_size', full_name='apollo.planning.WarmStartConfig.step_size', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_forward_penalty', full_name='apollo.planning.WarmStartConfig.traj_forward_penalty', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_back_penalty', full_name='apollo.planning.WarmStartConfig.traj_back_penalty', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_gear_switch_penalty', full_name='apollo.planning.WarmStartConfig.traj_gear_switch_penalty', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_penalty', full_name='apollo.planning.WarmStartConfig.traj_steer_penalty', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_change_penalty', full_name='apollo.planning.WarmStartConfig.traj_steer_change_penalty', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_a_star_xy_resolution', full_name='apollo.planning.WarmStartConfig.grid_a_star_xy_resolution', index=9,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_radius', full_name='apollo.planning.WarmStartConfig.node_radius', index=10,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_curve_config', full_name='apollo.planning.WarmStartConfig.s_curve_config', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1475,
)


_DUALVARIABLEWARMSTARTCONFIG = _descriptor.Descriptor(
  name='DualVariableWarmStartConfig',
  full_name='apollo.planning.DualVariableWarmStartConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_d', full_name='apollo.planning.DualVariableWarmStartConfig.weight_d', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DualVariableWarmStartConfig.ipopt_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qp_format', full_name='apollo.planning.DualVariableWarmStartConfig.qp_format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DualVariableWarmStartConfig.min_safety_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_osqp', full_name='apollo.planning.DualVariableWarmStartConfig.debug_osqp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta', full_name='apollo.planning.DualVariableWarmStartConfig.beta', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='osqp_config', full_name='apollo.planning.DualVariableWarmStartConfig.osqp_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1758,
)


_DISTANCEAPPROACHCONFIG = _descriptor.Descriptor(
  name='DistanceApproachConfig',
  full_name='apollo.planning.DistanceApproachConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_steer', full_name='apollo.planning.DistanceApproachConfig.weight_steer', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a', full_name='apollo.planning.DistanceApproachConfig.weight_a', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_rate', full_name='apollo.planning.DistanceApproachConfig.weight_steer_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_rate', full_name='apollo.planning.DistanceApproachConfig.weight_a_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_x', full_name='apollo.planning.DistanceApproachConfig.weight_x', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_y', full_name='apollo.planning.DistanceApproachConfig.weight_y', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_phi', full_name='apollo.planning.DistanceApproachConfig.weight_phi', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_v', full_name='apollo.planning.DistanceApproachConfig.weight_v', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_stitching', full_name='apollo.planning.DistanceApproachConfig.weight_steer_stitching', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_stitching', full_name='apollo.planning.DistanceApproachConfig.weight_a_stitching', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_first_order_time', full_name='apollo.planning.DistanceApproachConfig.weight_first_order_time', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_second_order_time', full_name='apollo.planning.DistanceApproachConfig.weight_second_order_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DistanceApproachConfig.min_safety_distance', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_forward', full_name='apollo.planning.DistanceApproachConfig.max_speed_forward', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_reverse', full_name='apollo.planning.DistanceApproachConfig.max_speed_reverse', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_forward', full_name='apollo.planning.DistanceApproachConfig.max_acceleration_forward', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_reverse', full_name='apollo.planning.DistanceApproachConfig.max_acceleration_reverse', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_time_sample_scaling', full_name='apollo.planning.DistanceApproachConfig.min_time_sample_scaling', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_time_sample_scaling', full_name='apollo.planning.DistanceApproachConfig.max_time_sample_scaling', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_fix_time', full_name='apollo.planning.DistanceApproachConfig.use_fix_time', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DistanceApproachConfig.ipopt_config', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_constraint_check', full_name='apollo.planning.DistanceApproachConfig.enable_constraint_check', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hand_derivative', full_name='apollo.planning.DistanceApproachConfig.enable_hand_derivative', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_derivative_check', full_name='apollo.planning.DistanceApproachConfig.enable_derivative_check', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_initial_final_check', full_name='apollo.planning.DistanceApproachConfig.enable_initial_final_check', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_approach_mode', full_name='apollo.planning.DistanceApproachConfig.distance_approach_mode', index=25,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_jacobian_ad', full_name='apollo.planning.DistanceApproachConfig.enable_jacobian_ad', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_check_initial_state', full_name='apollo.planning.DistanceApproachConfig.enable_check_initial_state', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_end_state', full_name='apollo.planning.DistanceApproachConfig.weight_end_state', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_slack', full_name='apollo.planning.DistanceApproachConfig.weight_slack', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1761,
  serialized_end=2742,
)


_IPOPTCONFIG = _descriptor.Descriptor(
  name='IpoptConfig',
  full_name='apollo.planning.IpoptConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipopt_print_level', full_name='apollo.planning.IpoptConfig.ipopt_print_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_mem_percent', full_name='apollo.planning.IpoptConfig.mumps_mem_percent', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_pivtol', full_name='apollo.planning.IpoptConfig.mumps_pivtol', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_max_iter', full_name='apollo.planning.IpoptConfig.ipopt_max_iter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_tol', full_name='apollo.planning.IpoptConfig.ipopt_tol', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_acceptable_constr_viol_tol', full_name='apollo.planning.IpoptConfig.ipopt_acceptable_constr_viol_tol', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_min_hessian_perturbation', full_name='apollo.planning.IpoptConfig.ipopt_min_hessian_perturbation', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_jacobian_regularization_value', full_name='apollo.planning.IpoptConfig.ipopt_jacobian_regularization_value', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_print_timing_statistics', full_name='apollo.planning.IpoptConfig.ipopt_print_timing_statistics', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_alpha_for_y', full_name='apollo.planning.IpoptConfig.ipopt_alpha_for_y', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_recalc_y', full_name='apollo.planning.IpoptConfig.ipopt_recalc_y', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_mu_init', full_name='apollo.planning.IpoptConfig.ipopt_mu_init', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2745,
  serialized_end=3122,
)


_OSQPCONFIG = _descriptor.Descriptor(
  name='OSQPConfig',
  full_name='apollo.planning.OSQPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alpha', full_name='apollo.planning.OSQPConfig.alpha', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_abs', full_name='apollo.planning.OSQPConfig.eps_abs', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_rel', full_name='apollo.planning.OSQPConfig.eps_rel', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_iter', full_name='apollo.planning.OSQPConfig.max_iter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polish', full_name='apollo.planning.OSQPConfig.polish', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='osqp_debug_log', full_name='apollo.planning.OSQPConfig.osqp_debug_log', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3125,
  serialized_end=3281,
)


_ITERATIVEANCHORINGCONFIG = _descriptor.Descriptor(
  name='IterativeAnchoringConfig',
  full_name='apollo.planning.IterativeAnchoringConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interpolated_delta_s', full_name='apollo.planning.IterativeAnchoringConfig.interpolated_delta_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reanchoring_trails_num', full_name='apollo.planning.IterativeAnchoringConfig.reanchoring_trails_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reanchoring_pos_stddev', full_name='apollo.planning.IterativeAnchoringConfig.reanchoring_pos_stddev', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reanchoring_length_stddev', full_name='apollo.planning.IterativeAnchoringConfig.reanchoring_length_stddev', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimate_bound', full_name='apollo.planning.IterativeAnchoringConfig.estimate_bound', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_bound', full_name='apollo.planning.IterativeAnchoringConfig.default_bound', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_shortest_dimension', full_name='apollo.planning.IterativeAnchoringConfig.vehicle_shortest_dimension', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.04),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fem_pos_deviation_smoother_config', full_name='apollo.planning.IterativeAnchoringConfig.fem_pos_deviation_smoother_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collision_decrease_ratio', full_name='apollo.planning.IterativeAnchoringConfig.collision_decrease_ratio', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.9),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_forward_v', full_name='apollo.planning.IterativeAnchoringConfig.max_forward_v', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_reverse_v', full_name='apollo.planning.IterativeAnchoringConfig.max_reverse_v', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_forward_acc', full_name='apollo.planning.IterativeAnchoringConfig.max_forward_acc', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_reverse_acc', full_name='apollo.planning.IterativeAnchoringConfig.max_reverse_acc', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acc_jerk', full_name='apollo.planning.IterativeAnchoringConfig.max_acc_jerk', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_t', full_name='apollo.planning.IterativeAnchoringConfig.delta_t', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_curve_config', full_name='apollo.planning.IterativeAnchoringConfig.s_curve_config', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3284,
  serialized_end=3917,
)


_TRAJECTORYPARTITIONCONFIG = _descriptor.Descriptor(
  name='TrajectoryPartitionConfig',
  full_name='apollo.planning.TrajectoryPartitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interpolated_pieces_num', full_name='apollo.planning.TrajectoryPartitionConfig.interpolated_pieces_num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_gear_check_horizon', full_name='apollo.planning.TrajectoryPartitionConfig.initial_gear_check_horizon', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_searching_range', full_name='apollo.planning.TrajectoryPartitionConfig.heading_searching_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_period_duration', full_name='apollo.planning.TrajectoryPartitionConfig.gear_shift_period_duration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_max_t', full_name='apollo.planning.TrajectoryPartitionConfig.gear_shift_max_t', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_unit_t', full_name='apollo.planning.TrajectoryPartitionConfig.gear_shift_unit_t', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3920,
  serialized_end=4162,
)

_PLANNEROPENSPACECONFIG.fields_by_name['roi_config'].message_type = _ROICONFIG
_PLANNEROPENSPACECONFIG.fields_by_name['warm_start_config'].message_type = _WARMSTARTCONFIG
_PLANNEROPENSPACECONFIG.fields_by_name['dual_variable_warm_start_config'].message_type = _DUALVARIABLEWARMSTARTCONFIG
_PLANNEROPENSPACECONFIG.fields_by_name['distance_approach_config'].message_type = _DISTANCEAPPROACHCONFIG
_PLANNEROPENSPACECONFIG.fields_by_name['iterative_anchoring_smoother_config'].message_type = _ITERATIVEANCHORINGCONFIG
_PLANNEROPENSPACECONFIG.fields_by_name['trajectory_partition_config'].message_type = _TRAJECTORYPARTITIONCONFIG
_WARMSTARTCONFIG.fields_by_name['s_curve_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PIECEWISEJERKSPEEDOPTIMIZERCONFIG
_DUALVARIABLEWARMSTARTCONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTCONFIG
_DUALVARIABLEWARMSTARTCONFIG.fields_by_name['qp_format'].enum_type = _DUALWARMUPMODE
_DUALVARIABLEWARMSTARTCONFIG.fields_by_name['osqp_config'].message_type = _OSQPCONFIG
_DISTANCEAPPROACHCONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTCONFIG
_DISTANCEAPPROACHCONFIG.fields_by_name['distance_approach_mode'].enum_type = _DISTANCEAPPROACHMODE
_ITERATIVEANCHORINGCONFIG.fields_by_name['fem_pos_deviation_smoother_config'].message_type = modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2._FEMPOSDEVIATIONSMOOTHERCONFIG
_ITERATIVEANCHORINGCONFIG.fields_by_name['s_curve_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PIECEWISEJERKSPEEDOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['PlannerOpenSpaceConfig'] = _PLANNEROPENSPACECONFIG
DESCRIPTOR.message_types_by_name['ROIConfig'] = _ROICONFIG
DESCRIPTOR.message_types_by_name['WarmStartConfig'] = _WARMSTARTCONFIG
DESCRIPTOR.message_types_by_name['DualVariableWarmStartConfig'] = _DUALVARIABLEWARMSTARTCONFIG
DESCRIPTOR.message_types_by_name['DistanceApproachConfig'] = _DISTANCEAPPROACHCONFIG
DESCRIPTOR.message_types_by_name['IpoptConfig'] = _IPOPTCONFIG
DESCRIPTOR.message_types_by_name['OSQPConfig'] = _OSQPCONFIG
DESCRIPTOR.message_types_by_name['IterativeAnchoringConfig'] = _ITERATIVEANCHORINGCONFIG
DESCRIPTOR.message_types_by_name['TrajectoryPartitionConfig'] = _TRAJECTORYPARTITIONCONFIG
DESCRIPTOR.enum_types_by_name['DualWarmUpMode'] = _DUALWARMUPMODE
DESCRIPTOR.enum_types_by_name['DistanceApproachMode'] = _DISTANCEAPPROACHMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlannerOpenSpaceConfig = _reflection.GeneratedProtocolMessageType('PlannerOpenSpaceConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLANNEROPENSPACECONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlannerOpenSpaceConfig)
  })
_sym_db.RegisterMessage(PlannerOpenSpaceConfig)

ROIConfig = _reflection.GeneratedProtocolMessageType('ROIConfig', (_message.Message,), {
  'DESCRIPTOR' : _ROICONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ROIConfig)
  })
_sym_db.RegisterMessage(ROIConfig)

WarmStartConfig = _reflection.GeneratedProtocolMessageType('WarmStartConfig', (_message.Message,), {
  'DESCRIPTOR' : _WARMSTARTCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.WarmStartConfig)
  })
_sym_db.RegisterMessage(WarmStartConfig)

DualVariableWarmStartConfig = _reflection.GeneratedProtocolMessageType('DualVariableWarmStartConfig', (_message.Message,), {
  'DESCRIPTOR' : _DUALVARIABLEWARMSTARTCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DualVariableWarmStartConfig)
  })
_sym_db.RegisterMessage(DualVariableWarmStartConfig)

DistanceApproachConfig = _reflection.GeneratedProtocolMessageType('DistanceApproachConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCEAPPROACHCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DistanceApproachConfig)
  })
_sym_db.RegisterMessage(DistanceApproachConfig)

IpoptConfig = _reflection.GeneratedProtocolMessageType('IpoptConfig', (_message.Message,), {
  'DESCRIPTOR' : _IPOPTCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.IpoptConfig)
  })
_sym_db.RegisterMessage(IpoptConfig)

OSQPConfig = _reflection.GeneratedProtocolMessageType('OSQPConfig', (_message.Message,), {
  'DESCRIPTOR' : _OSQPCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OSQPConfig)
  })
_sym_db.RegisterMessage(OSQPConfig)

IterativeAnchoringConfig = _reflection.GeneratedProtocolMessageType('IterativeAnchoringConfig', (_message.Message,), {
  'DESCRIPTOR' : _ITERATIVEANCHORINGCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.IterativeAnchoringConfig)
  })
_sym_db.RegisterMessage(IterativeAnchoringConfig)

TrajectoryPartitionConfig = _reflection.GeneratedProtocolMessageType('TrajectoryPartitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYPARTITIONCONFIG,
  '__module__' : 'modules.planning.proto.planner_open_space_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrajectoryPartitionConfig)
  })
_sym_db.RegisterMessage(TrajectoryPartitionConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_yield_sign.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2
from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_yield_sign.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/map/proto/map_yield_sign.proto\x12\x0c\x61pollo.hdmap\x1a\x1emodules/map/proto/map_id.proto\x1a$modules/map/proto/map_geometry.proto\"w\n\tYieldSign\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\tstop_line\x18\x02 \x03(\x0b\x32\x13.apollo.hdmap.Curve\x12$\n\noverlap_id\x18\x03 \x03(\x0b\x32\x10.apollo.hdmap.Id'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])




_YIELDSIGN = _descriptor.Descriptor(
  name='YieldSign',
  full_name='apollo.hdmap.YieldSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.YieldSign.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='apollo.hdmap.YieldSign.stop_line', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.hdmap.YieldSign.overlap_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=245,
)

_YIELDSIGN.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_YIELDSIGN.fields_by_name['stop_line'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_YIELDSIGN.fields_by_name['overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
DESCRIPTOR.message_types_by_name['YieldSign'] = _YIELDSIGN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YieldSign = _reflection.GeneratedProtocolMessageType('YieldSign', (_message.Message,), {
  'DESCRIPTOR' : _YIELDSIGN,
  '__module__' : 'modules.map.proto.map_yield_sign_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.YieldSign)
  })
_sym_db.RegisterMessage(YieldSign)


# @@protoc_insertion_point(module_scope)
